<template>
	<div class="system-user-container">
		<el-card shadow="hover">
			<div class="system-user-search mb15">
				<el-input size="default" v-model="listQuery.searchParams.name" placeholder="物资名称" style="max-width: 215px" />
				<el-button size="default" type="primary" class="ml10" @click="listApi"> 查询 </el-button>
				<el-button size="default" class="ml10" @click="submitReset"> 重置 </el-button>
			</div>
			<div class="button_Line">
				<div class="button_Left">
					<el-button size="default" type="primary" @click="onOpenAdd">
						<el-icon> <Plus /> </el-icon>新建
					</el-button>
					<el-button size="default" type="warning" plain :disabled="warning">
						<el-icon> <Edit /> </el-icon>修改
					</el-button>
					<el-button size="default" type="danger" plain @click="onDeleteAll" :disabled="danger">
						<el-icon> <Delete /> </el-icon>删除
					</el-button>
				</div>
				<div class="button_Right">
					<!--          <el-button @click="upButton">-->
					<!--						<el-icon>-->
					<!--							<Upload />-->
					<!--						</el-icon>-->
					<!--					</el-button>-->
					<!--					<el-button>-->
					<!--						<el-icon>-->
					<!--							<Refresh />-->
					<!--						</el-icon>-->
					<!--					</el-button>-->
				</div>
			</div>
			<el-table :data="tableData" style="width: 100%" ref="multipleTableRef" @selection-change="handleSelectionChange">
				<el-table-column align="center" type="selection" width="55" />
				<el-table-column align="center" prop="name" label="物资名称" min-width="120" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="number" label="物资编号" min-width="120" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="deptName" label="负责部门" min-width="120" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" label="物资分类" min-width="120" show-overflow-tooltip sortable>
					<template #default="scope">
						<span v-if="scope.row.classification == 1">事故气体吸收装置</span><span v-if="scope.row.classification == 2">通讯设施</span
						><span v-if="scope.row.classification == 3">交通运输工具</span><span v-if="scope.row.classification == 4">照明装置</span
						><span v-if="scope.row.classification == 5">防护器材</span><span v-if="scope.row.classification == 6">其它</span>
					</template>
				</el-table-column>
				<el-table-column align="center" prop="place" label="存放位置" min-width="120" show-overflow-tooltip sortable></el-table-column>
				<el-table-column align="center" prop="count" label="存储数量" min-width="120" show-overflow-tooltip sortable></el-table-column>
				<el-table-column label="操作" width="200" align="center" fixed="right">
					<template #default="scope">
						<el-button size="small" text type="primary" @click="onMaintain(scope.row)">
							<el-icon style="margin-right: 5px"> <EditPen /> </el-icon>保养
						</el-button>
						<el-button size="small" text type="primary" @click="onInspect(scope.row)">
							<el-icon style="margin-right: 5px"> <EditPen /> </el-icon>检查
						</el-button>
						<el-button size="small" text type="primary" @click="onEdit('详情', scope.row.id)">
							<el-icon style="margin-right: 5px"> <View /> </el-icon>查看
						</el-button>
						<el-button size="small" text type="primary" @click="onEdit('修改', scope.row.id)">
							<el-icon style="margin-right: 5px">
								<EditPen />
							</el-icon>
							修改
						</el-button>
						<el-button size="small" text type="primary" @click="onRowDel(scope.row.id)">
							<el-icon> <Delete /> </el-icon>删除
						</el-button>
					</template>
				</el-table-column>
			</el-table>
			<div class="pages">
				<el-pagination
					v-if="tableData.length == 0 ? false : true"
					v-model:currentPage="pageIndex"
					v-model:page-size="pageSize"
					:page-sizes="[10, 20, 30]"
					:pager-count="5"
					layout="total, sizes, prev, pager, next, jumper"
					:total="total"
					@size-change="handleSizeChange"
					@current-change="handleCurrentChange"
				/>
			</div>
		</el-card>
		<Maintain ref="seeRef" @myadd="onMaintainAdd" />
		<Inspect ref="spectRef" @myadd="onInspectAdd" />
		<OpenAdd ref="addRef" @myAdd="onMyAdd" />
		<OpenEdit ref="editRef" @myAdd="onMyAdds" />
		<!--		<upData ref="upShow"></upData>-->
	</div>
</template>

<script lang="ts">
import { ref, defineComponent, reactive, onMounted } from 'vue';
import {
	ElMessageBox,
	ElMessage,
	// ElTable
} from 'element-plus';
import { Plus, Edit, Delete, Upload, Refresh, View, EditPen } from '@element-plus/icons-vue';
import OpenAdd from '/@/views/contingencyManagement/emergencyResources/emergencySupplies/component/openAdd.vue';
import Maintain from '/@/views/contingencyManagement/emergencyResources/emergencySupplies/component/maintain.vue';
import Inspect from '/@/views/contingencyManagement/emergencyResources/emergencySupplies/component/inspect.vue';
import OpenEdit from '/@/views/contingencyManagement/emergencyResources/emergencySupplies/component/openEdit.vue';
import UpData from '/@/views/contingencyManagement/panManagement/component/upData.vue';
import { emergencySuppliesApi } from '/@/api/contingencyManagement/emergencyResources';

export default defineComponent({
	name: 'systemUser',
	components: {
		OpenAdd,
		Maintain,
		View,
		OpenEdit,
		EditPen,
		Plus,
		Edit,
		Delete,
		Upload,
		// Download,
		Inspect,
		Refresh,
		UpData,
	},
	setup() {
		// 列表参数
		const listQuery = reactive({
			pageIndex: 1,
			pageSize: 10,
			searchParams: {
				name: '',
			},
		});
		// 定义表格数据
		const tableData = ref([]);
		// 请求列表数据
		const listApi = async () => {
			let res = await emergencySuppliesApi().getEmergencySuppliesList(listQuery);
			// console.log(res);
			if (res.data.code == 200) {
				tableData.value = res.data.data;
				pageIndex.value = res.data.pageIndex;
				pageSize.value = res.data.pageSize;
				total.value = res.data.total;
			} else {
				ElMessage.error(res.data.msg);
			}
		};
		//重置
		const submitReset = () => {
			listQuery.searchParams.name = '';
			listApi();
		};
		const warning = ref(true);
		const danger = ref(true);
		const deletAll = ref();
		const handleSelectionChange = (val: any) => {
			let valId = JSON.parse(JSON.stringify(val));
			let arr = [];
			for (let i = 0; i < valId.length; i++) {
				arr.push(valId[i].id);
			}
			deletAll.value = arr;
			// console.log(deletAll.value);
			if (val.length == 1) {
				warning.value = false;
				danger.value = false;
			} else if (val.length == 0) {
				warning.value = true;
				danger.value = true;
			} else {
				warning.value = true;
				danger.value = false;
			}
		};
		// 页面加载时
		onMounted(() => {
			listApi();
		});
		// 上传
		// const upShow = ref();
		// const upButton = () => {
		// 	upShow.value.openDialog();
		// };

		//新增应急物资检查弹窗
		const seeRef = ref();
		const onMaintain = (data: any) => {
			seeRef.value.openDialog(data);
		};
		// 应急物资保养新增后刷新
		const onMaintainAdd = () => {
			listApi();
		};
		//修改应急物资检查弹窗
		const spectRef = ref();
		const onInspect = (data: any) => {
			spectRef.value.openDialog(data);
		};
		// 应急物资检查新增后刷新
		const onInspectAdd = (e: boolean) => {
			if (e) {
				listApi();
			} else {
				listApi();
			}
		};
		// 新建应急物资代码弹窗
		const addRef = ref();
		const onOpenAdd = () => {
			addRef.value.openDialog('新建应急物资代码', false);
		};
		// 新增后刷新
		const onMyAdd = (e: boolean) => {
			if (e) {
				listApi();
			} else {
				listApi();
			}
		};
		// 打开修改用户弹窗
		const editRef = ref();
		const onEdit = (val: string, row: object) => {
			if (val == '详情') {
				editRef.value.openDialog('查看应急物资代码', row, true);
			} else {
				editRef.value.openDialog('修改应急物资代码', row, false);
			}
		};
		// 新增后刷新
		const onMyAdds = (e: boolean) => {
			if (e) {
				listApi();
			} else {
				listApi();
			}
		};
		// 删除用户
		const onRowDel = (id: number) => {
			let arr = [];
			arr.push(id);
			ElMessageBox.confirm('确定删除所选项吗?', '提示', {
				confirmButtonText: '确认',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					emergencySuppliesApi()
						.deleteEmergencySupplies(arr)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'error',
								});
								listApi();
							}
						});
				})
				.catch(() => {});
		};
		// 多选删除
		const onDeleteAll = () => {
			ElMessageBox.confirm('确定删除所选项吗?', '提示', {
				confirmButtonText: '确定',
				cancelButtonText: '取消',
				type: 'warning',
			})
				.then(() => {
					emergencySuppliesApi()
						.deleteEmergencySupplies(deletAll.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'success',
								});
								listApi();
							} else {
								ElMessage({
									showClose: true,
									message: res.data.msg,
									type: 'error',
								});
								listApi();
							}
						});
				})
				.catch(() => {});
		};
		// 分页
		const pageIndex = ref();
		const pageSize = ref();
		const total = ref();
		// 分页条数
		const handleSizeChange = (val: number) => {
			// console.log(`${val} items per page`);
			listQuery.pageSize = val;
		};
		// 分页数
		const handleCurrentChange = (val: number) => {
			// console.log(`current page: ${val}`);
			listQuery.pageIndex = val;
		};
		return {
			// upButton,
			// upShow,
			tableData,
			onMaintain, //保养
			seeRef,
			onOpenAdd, //新增
			addRef,
			onRowDel,
			pageIndex,
			pageSize,
			total,
			handleSizeChange,
			handleCurrentChange,
			listQuery,
			listApi,
			onMounted,
			submitReset,
			onMyAdd,
			onEdit,
			editRef,
			onDeleteAll,
			handleSelectionChange,
			warning,
			danger,
			spectRef,
			onInspect,
			onMaintainAdd,
			onInspectAdd,
			onMyAdds,
		};
	},
});
</script>
<style scoped lang="scss">
.table_Box {
	padding: 20px;
	background-color: #fff;
}
.tableForm {
	margin-top: 10px;
}
/*按钮行*/
.button_Line {
	display: flex;
	flex-direction: row;
	justify-content: space-between;
}
//分页
.pages {
	display: flex;
	justify-content: flex-end;
	margin-top: 15px;
}
::v-deep .el-pagination .el-pager li {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination .el-pager li.is-active {
	background-color: #409eff;
	color: #fff;
}
::v-deep .el-pagination .btn-prev {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
::v-deep .el-pagination button:disabled {
	color: #c0c4cc;
}
::v-deep .el-pagination .btn-next {
	margin: 0 5px;
	background-color: #f4f4f5;
	color: #606266;
	min-width: 30px;
	border-radius: 2px;
}
</style>